@@ -59,7 +59,7 @@ class PrefetchUnit(Process):
                     item = item if self.processing_func is None else self.processing_func(item)
                     if isinstance(item, Generator):
                         for _item in item:
-                            self.queue.put((item, self.gid, idx, False))
+                            self.queue.put((_item, self.gid, idx, False))
                             idx += 1
                     else:
                         self.queue.put((item, self.gid, idx, False))
